# Intel Boards

The {py:mod}`torii.platform.vendor.intel` module provides a base platform to support Intel toolchains with the [Quartus] and [Mistral] toolchains.

```{eval-rst}

.. automodule:: torii_boards.intel.arrow_deca
	:members:
	:undoc-members:

.. automodule:: torii_boards.intel.chameleon96
	:members:
	:undoc-members:

.. automodule:: torii_boards.intel.de0_cv
	:members:
	:undoc-members:

.. automodule:: torii_boards.intel.de0
	:members:
	:undoc-members:

.. automodule:: torii_boards.intel.de1_soc
	:members:
	:undoc-members:

.. automodule:: torii_boards.intel.de10_lite
	:members:
	:undoc-members:

.. automodule:: torii_boards.intel.de10_nano
	:members:
	:undoc-members:

.. automodule:: torii_boards.intel.mister
	:members:
	:undoc-members:

.. automodule:: torii_boards.intel.rz_easyfpga_a2_2
	:members:
	:undoc-members:

```


[Quartus]: https://www.intel.com/content/www/us/en/products/details/fpga/development-tools/quartus-prime.html
[Mistral]: https://github.com/Ravenslofty/mistral
